@@ -92,8 +92,9 @@ class Config:
 
     DEFAULT_NEWLINE = 'auto'
     DEFAULT_ENCODING = 'utf-8'
-
-    def __init__(self):
+    AMBIGUOUS_WIDTH = 1
+    
+    def __init__(self, option):
         kaadir = os.path.abspath(
                  os.path.expandvars(
                  os.path.expanduser(consts.KAA_DIR)))
@@ -109,14 +110,12 @@ class Config:
         if not os.path.exists(histdir):
             os.mkdir(histdir)
 
-        userdir = os.path.join(kaadir, 'kaa')
-        if not os.path.exists(userdir):
-            os.mkdir(userdir)
-
         self.KAADIR = kaadir
         self.LOGDIR = logdir
         self.HISTDIR = histdir
 
+        self.palette = option.palette
+        
     def init_history(self):
         self.hist_storage = KaaHistoryStorage(
             os.path.join(self.HISTDIR, consts.HIST_DBNAME))
