@@ -9,21 +9,27 @@ from kaa.exceptions import KaaError
 
 class CuiApp:
     SHOW_MENU_MESSAGE = 'Type F1 or alt+/ for menu.'
-    DEFAULT_THEME = 'default'
+    DEFAULT_THEME = 'basic'
+    DEFAULT_PALETTE = 'dark'
     MAX_CLIPBOARD = 10
     
     def __init__(self, config):
         self.config = config
+        self.colors = None
         self._idleprocs = None
-        self.colors = color.Colors()
         self.lastcommands = ()
         self.focus = None
         self._clipboard = []
         self._quit = False
-        self._theme_name = self.DEFAULT_THEME
+        self.theme = self.DEFAULT_THEME
         self.last_dir = '.'
 
     def init(self, mainframe):
+        if self.config.palette:
+            self.set_palette(self.config.palette)
+        elif not self.colors:
+            self.set_palette(self.DEFAULT_PALETTE)
+            
         self.config.init_history()
         
         self.messagebar = messagebarmode.MessageBarMode()
@@ -51,8 +57,18 @@ class CuiApp:
         self.config.hist_grepfiles.close()
 
     def get_current_theme(self):
-        return self._theme_name
+        return self.theme
 
+    def set_palette(self, name):
+        palette = self.get_palette(name)
+        self.colors = color.Colors(palette)
+
+    def get_palette(self, name):
+        if name == 'light':
+            return color.LightPalette()
+        else:
+            return color.DarkPalette()
+            
     def quit(self):
         self._quit = True
 
