@@ -52,7 +52,9 @@ class EditMode:
         return None, None, candidates
 
     def _on_str(self, wnd, s):
-        self.pending_str += s
+        for c in s:
+            if c == '\t' or c >= ' ':
+                self.pending_str += c
 
     def on_key_pressed(self, wnd, event):
         s, commands, candidate = self._get_command(wnd, event)
