@@ -1,7 +1,7 @@
 from kaa.theme import Theme, Style
 
 DefaultThemes = {
-    'default':
+    'basic':
         Theme([
             Style('default', 'default', 'default'),
             Style('lineno', 'White', 'Blue'),
@@ -12,5 +12,6 @@ DefaultThemes = {
             Style('comment', 'Cyan', 'default'),
             Style('string', 'Blue', 'default'),
             Style('number', 'Green', 'default'),
-        ])
+        ]),
+    
 }
