@@ -6,9 +6,9 @@ from kaa.theme import Theme, Style
 from kaa.keyboard import *
 
 FrameListThemes = {
-    'default':
+    'basic':
         Theme([
-        ])
+        ]), 
 }
 
 framelist_keys = {
