@@ -3,11 +3,11 @@ from kaa.filetype.default import modebase
 from kaa.theme import Theme, Style
 
 MessageBarThemes = {
-    'default':
+    'basic':
         Theme([
-            Style('default', 'Base3', 'Base03'),
+            Style('default', 'Base3', 'default'),
             Style('rec', 'Base3', 'red'),
-        ])
+        ]),
 }
 
 class MessageBarMode(modebase.ModeBase):
