@@ -10,9 +10,10 @@ from kaa.ui.selectlist import filterlist
 from gappedbuf.sre_constants import error as gre_error
 
 SearchThemes = {
-    'default':
+    'basic':
         Theme([
-        ])
+        ]),
+
 }
 
 
