@@ -16,9 +16,9 @@ import kaa.filetype.default.keybind
 
 
 FileOpenDlgThemes = {
-    'default':
+    'basic':
         Theme([
-        ])
+        ]),
 }
 
 class DirFileListMode(selectlist.SelectItemList):
@@ -71,9 +71,9 @@ class DirFileListMode(selectlist.SelectItemList):
         self.update_doc(items)
 
 FileNameDlgThemes = {
-    'default':
+    'basic':
         Theme([
-        ])
+        ]),
 }
 
 
@@ -169,7 +169,14 @@ class FileOpenDlgCommands(Commands):
     def openfile(self, wnd):
         filename = self._build_filename(wnd)
         if os.path.isfile(filename):
-            wnd.document.mode.callback(filename, wnd.document.mode.encoding,
+            enc = wnd.document.mode.encoding
+            if enc == 'japanese':
+                enc = kaa.app.storage.guess_japanese_encoding(filename)
+                if not enc:
+                    kaa.app.messagebar.set_message('Cannot detect text encoding.')
+                    return
+                    
+            wnd.document.mode.callback(filename, enc,
                                        wnd.document.mode.newline)
             popup = wnd.get_label('popup')
             popup.destroy()
@@ -300,12 +307,18 @@ class OpenFilenameDlgMode(dialogmode.DialogMode):
         wnd.screen.selection.set_range(f, f+len(s))
         wnd.cursor.setpos(f+len(s))
 
+    def _get_encnames(self):
+        return sorted(encodingdef.encodings + ['japanese'],
+                 key=lambda k:k.upper())
+
     def select_encoding(self, wnd):
+        encnames = self._get_encnames()
+        
         def callback(n):
             if n is None:
                 return
 
-            enc = encodingdef.encodings[n]
+            enc = encnames[n]
             if enc != self.encoding:
                 self.encoding = enc
                 f, t = self.document.marks['enc']
@@ -315,8 +328,8 @@ class OpenFilenameDlgMode(dialogmode.DialogMode):
 
         doc = itemlistmode.ItemListMode.build(
             'Select character encoding:',
-            encodingdef.encodings,
-            encodingdef.encodings.index(self.encoding),
+            encnames,
+            encnames.index(self.encoding),
             callback)
 
         kaa.app.show_dialog(doc)
@@ -425,6 +438,10 @@ class SaveAsFilenameDlgMode(OpenFilenameDlgMode):
         self.fileopendlg_commands = FileSaveAsDlgCommands()
         self.register_command(self.fileopendlg_commands)
 
+    def _get_encnames(self):
+        return sorted(encodingdef.encodings,
+                 key=lambda k:k.upper())
+
 def show_filesaveas(filename, encoding, newline, callback):
     if not filename:
         filename = kaa.app.last_dir
